@@ -1,3 +1,4 @@
+
 from loguru import logger
 import configparser
 
@@ -21,3 +22,5 @@ def write_logger(msg, t="info"):
         logger.error(msg)
     elif t == "warning":
         logger.warning(msg)
+    elif t == "debug":
+        logger.debug(msg)
