@@ -1,3 +1,5 @@
+
+import asyncio
 from abc import ABCMeta, abstractmethod
 from kordar_task import write_logger
 
@@ -46,3 +48,24 @@ class DefaultTask(itask):
 
     def execute(self, body):
         write_logger("defaultTask, name = %s" % body.task_id())
+
+
+class DefaultAsyncBody(ibody):
+    def __init__(self, tid):
+        self.id = tid
+
+    def task_id(self):
+        return "default-kordar_async_task"
+
+
+class DefaultAsyncTask(itask):
+    def id(self):
+        return "default-kordar_async_task"
+
+    async def execute(self, body):
+        i = 0
+        while i < 5:
+            write_logger("DefaultAsyncTask, id = %s" % body.id)
+            i = i + 1
+            await asyncio.sleep(1)
+
